@@ -37,7 +37,7 @@ use crate::{
             ConsensusProtocol, EraReport, FinalizedBlock as CpFinalizedBlock, ProposedBlock,
             ProtocolOutcome, ProtocolOutcomes,
         },
-        metrics::ConsensusMetrics,
+        metrics::Metrics,
         traits::NodeIdT,
         validator_change::ValidatorChanges,
         ActionId, Config, ConsensusMessage, Event, NewBlockPayload, ReactorEventT, ResolveValidity,
@@ -103,7 +103,7 @@ pub struct EraSupervisor<I> {
     /// The height of the next block to be executed. If this falls too far behind, we pause.
     next_executed_height: u64,
     #[data_size(skip)]
-    metrics: ConsensusMetrics,
+    metrics: Metrics,
     /// The path to the folder where unit files will be stored.
     unit_files_folder: PathBuf,
     /// The next upgrade activation point. When the era immediately before the activation point is
@@ -151,8 +151,8 @@ where
         let (root, config) = config.into_parts();
         let (secret_signing_key, public_signing_key) = config.load_keys(root)?;
         info!(our_id = %public_signing_key, "EraSupervisor pubkey",);
-        let metrics = ConsensusMetrics::new(registry)
-            .expect("failure to setup and register ConsensusMetrics");
+        let metrics =
+            Metrics::new(registry).expect("failed to set up and register consensus metrics");
         let activation_era_id = protocol_config.last_activation_point;
         let auction_delay = protocol_config.auction_delay;
         #[allow(clippy::integer_arithmetic)] // Block height should never reach u64::MAX.
