@@ -32,6 +32,7 @@ mod gossiped_address;
 mod limiter;
 mod message;
 mod message_pack_format;
+mod metrics;
 mod outgoing;
 mod symmetry;
 pub(crate) mod tasks;
@@ -71,24 +72,28 @@ use tokio_util::codec::LengthDelimitedCodec;
 use tracing::{debug, error, info, trace, warn, Instrument, Span};
 
 use self::{
+    chain_info::ChainInfo,
     counting_format::{ConnectionId, CountingFormat, Role},
     error::{ConnectionError, Result},
     event::{IncomingConnection, OutgoingConnection},
     limiter::Limiter,
     message::ConsensusKeyPair,
     message_pack_format::MessagePackFormat,
+    metrics::Metrics,
     outgoing::{DialOutcome, DialRequest, OutgoingConfig, OutgoingManager},
     symmetry::ConnectionSymmetry,
     tasks::NetworkContext,
 };
 pub(crate) use self::{
+    config::Config,
+    error::Error,
     event::Event,
     gossiped_address::GossipedAddress,
     message::{Message, MessageKind, Payload, PayloadWeights},
 };
 use super::{consensus, contract_runtime::ContractRuntimeAnnouncement};
 use crate::{
-    components::{networking_metrics::NetworkingMetrics, Component},
+    components::Component,
     effect::{
         announcements::{BlocklistAnnouncement, NetworkAnnouncement},
         requests::{NetworkInfoRequest, NetworkRequest, StorageRequest},
@@ -100,9 +105,6 @@ use crate::{
     utils::{self, display_error, WithDir},
     NodeRng,
 };
-use chain_info::ChainInfo;
-pub(crate) use config::Config;
-pub(crate) use error::Error;
 
 const MAX_METRICS_DROP_ATTEMPTS: usize = 25;
 const DROP_RETRY_DELAY: Duration = Duration::from_millis(100);
@@ -166,7 +168,7 @@ where
 
     /// Networking metrics.
     #[data_size(skip)]
-    net_metrics: Arc<NetworkingMetrics>,
+    net_metrics: Arc<Metrics>,
 
     /// The outgoing bandwidth limiter.
     #[data_size(skip)]
@@ -245,7 +247,7 @@ where
         let mut public_addr =
             utils::resolve_address(&cfg.public_address).map_err(Error::ResolveAddr)?;
 
-        let net_metrics = Arc::new(NetworkingMetrics::new(registry)?);
+        let net_metrics = Arc::new(Metrics::new(registry)?);
 
         // We can now create a listener.
         let bind_address = utils::resolve_address(&cfg.bind_address).map_err(Error::ResolveAddr)?;
@@ -1021,7 +1023,7 @@ pub(crate) type FramedTransport<P> = tokio_serde::Framed<
 
 /// Constructs a new framed transport on a stream.
 fn framed<P>(
-    metrics: Weak<NetworkingMetrics>,
+    metrics: Weak<Metrics>,
     connection_id: ConnectionId,
     stream: Transport,
     role: Role,
