@@ -37,22 +37,24 @@
 //! The following chart illustrates the lifecycle of an outgoing connection.
 //!
 //! ```text
-//!                            learn
-//!                          ┌──────────────  unknown/forgotten
-//!                          │ ┌───────────►  (implicit state)
-//!                          │ │
-//!                          │ │ exceed fail  │
-//!                          │ │ limit        │ block
-//!                          │ │              │
-//!                          │ │              │
-//!                          │ │              ▼
-//!     ┌─────────┐ fail,    │ │        ┌─────────┐
-//!     │         │ sweep    │ │  block │         │
-//!     │ Waiting │◄───────┐ │ │ ┌─────►│ Blocked │◄──────────┐
-//! ┌───┤         │        │ │ │ │      │         │           │
-//! │   └────┬────┘        │ │ │ │      └────┬────┘           │
-//! │ block  │             │ │ │ │           │                │
-//! │        │ timeout     │ ▼ │ │           │ redeem,        │
+//!                   forget (after n tries)
+//!          ┌────────────────────────────────────┐
+//!          │                 learn              ▼
+//!          │               ┌──────────────  unknown/forgotten
+//!          │               │                (implicit state)
+//!          │               │
+//!          │               │                │
+//!          │               │                │ block
+//!          │               │                │
+//!          │               │                │
+//!          │               │                ▼
+//!     ┌────┴────┐          │          ┌─────────┐
+//!     │         │  fail    │    block │         │
+//!     │ Waiting │◄───────┐ │   ┌─────►│ Blocked │◄──────────┐
+//! ┌───┤         │        │ │   │      │         │           │
+//! │   └────┬────┘        │ │   │      └────┬────┘           │
+//! │ block  │             │ │   │           │                │
+//! │        │ timeout     │ ▼   │           │ redeem,        │
 //! │        │        ┌────┴─────┴───┐       │ block timeout  │
 //! │        │        │              │       │                │
 //! │        └───────►│  Connecting  │◄──────┘                │
@@ -69,6 +71,7 @@
 //! │       │                                                 │
 //! │       │ block                                           │
 //! └───────┴─────────────────────────────────────────────────┘
+//! ```
 //!
 //! # Timeouts/safety
 //!
@@ -85,7 +88,6 @@
 //! If a conflict (multiple successful dial results) occurs, the more recent connection takes
 //! precedence over the previous one. This prevents problems when a notification of a terminated
 //! connection is overtaken by the new connection announcement.
-//! ```
 
 // Clippy has a lot of false positives due to `span.clone()`-closures.
 #![allow(clippy::redundant_clone)]
@@ -699,10 +701,18 @@ where
             DialOutcome::Failed { addr, error, when } => {
                 info!(err = display_error(&error), "outgoing connection failed");
 
-                let failures_so_far: Option<_> = if let Some(outgoing) = self.outgoing.get(&addr) {
+                if let Some(outgoing) = self.outgoing.get(&addr) {
                     match outgoing.state {
                         OutgoingState::Connecting { failures_so_far,.. } => {
-                            Some(failures_so_far + 1)
+                            self.change_outgoing_state(
+                                addr,
+                                OutgoingState::Waiting {
+                                    failures_so_far: failures_so_far + 1,
+                                    error: Some(error),
+                                    last_failure: when,
+                                },
+                            );
+                            None
                         }
                         OutgoingState::Blocked { .. } => {
                             debug!("failed dial outcome after block ignored");
@@ -718,7 +728,6 @@ where
                                 "processing dial outcome on a connection that was not marked as connecting or blocked"
                             );
 
-                            // Ensure we do not override the existing state, return early.
                             None
                         }
                     }
@@ -727,21 +736,7 @@ where
 
                     // If the connection does not exist, do not introduce it!
                     None
-                };
-
-                // If we had actual failure we are going to honor, set the waiting state.
-                if let Some(failures_so_far) = failures_so_far {
-                    self.change_outgoing_state(
-                        addr,
-                        OutgoingState::Waiting {
-                            failures_so_far,
-                            error: Some(error),
-                            last_failure: when,
-                        },
-                    );
                 }
-
-                None
             }
             DialOutcome::Loopback { addr } => {
                 info!("found loopback address");
