@@ -1,17 +1,27 @@
 //! Unit tests for the storage component.
 
-use std::{borrow::Cow, collections::HashMap};
+use std::{
+    borrow::Cow,
+    collections::{HashMap, HashSet},
+    convert::TryFrom,
+    fs::{self, File},
+};
 
-use lmdb::Transaction;
+use lmdb::{Cursor, Transaction};
 use rand::{prelude::SliceRandom, Rng};
 use serde::{de::DeserializeOwned, Deserialize, Serialize};
 use smallvec::smallvec;
 
+use casper_hashing::Digest;
 use casper_types::{EraId, ExecutionResult, ProtocolVersion, PublicKey, SecretKey};
 
-use super::{Config, Storage};
+use super::{
+    construct_block_body_to_block_header_reverse_lookup, garbage_collect_block_body_v2_db,
+    move_storage_files_to_network_subdir, should_move_storage_files_to_network_subdir, Config,
+    Storage,
+};
 use crate::{
-    components::storage::lmdb_ext::WriteTransactionExt,
+    components::storage::lmdb_ext::{TransactionExt, WriteTransactionExt},
     crypto::AsymmetricKeyExt,
     effect::{
         requests::{StateStoreRequest, StorageRequest},
@@ -20,7 +30,7 @@ use crate::{
     testing::{ComponentHarness, TestRng, UnitTestEvent},
     types::{
         Block, BlockHash, BlockHeader, BlockSignatures, Deploy, DeployHash, DeployMetadata,
-        FinalitySignature,
+        FinalitySignature, HashingAlgorithmVersion,
     },
     utils::WithDir,
 };
@@ -54,6 +64,7 @@ fn storage_fixture(harness: &ComponentHarness<UnitTestEvent>) -> Storage {
         None,
         ProtocolVersion::from_parts(1, 0, 0),
         false,
+        "test",
     )
     .expect("could not create storage component fixture")
 }
@@ -75,6 +86,30 @@ fn storage_fixture_with_hard_reset(
         Some(reset_era_id),
         ProtocolVersion::from_parts(1, 1, 0),
         false,
+        "test",
+    )
+    .expect("could not create storage component fixture")
+}
+
+/// Storage component test fixture.
+///
+/// Creates a storage component in a temporary directory, but with a hard reset to a specified era.
+///
+/// # Panics
+///
+/// Panics if setting up the storage fixture fails.
+fn storage_fixture_with_hard_reset_and_protocol_version(
+    harness: &ComponentHarness<UnitTestEvent>,
+    reset_era_id: EraId,
+    protocol_version: ProtocolVersion,
+) -> Storage {
+    let cfg = new_config(harness);
+    Storage::new(
+        &WithDir::new(harness.tmp.path(), cfg),
+        Some(reset_era_id),
+        protocol_version,
+        false,
+        "test",
     )
     .expect("could not create storage component fixture")
 }
@@ -211,6 +246,7 @@ fn get_highest_block(
 }
 
 /// Loads state from the storage component.
+#[cfg(test)]
 fn load_state<T>(
     harness: &mut ComponentHarness<UnitTestEvent>,
     storage: &mut Storage,
@@ -420,7 +456,7 @@ fn test_get_block_header_and_finality_signatures_by_height() {
 
     {
         let block_header = storage
-            .read_block_header_by_hash(block.hash())
+            .get_block_header_by_hash(block.hash())
             .expect("should not throw exception")
             .expect("should not be None");
         assert_eq!(
@@ -642,16 +678,6 @@ fn can_retrieve_store_and_load_deploys() {
     let response = get_deploys(&mut harness, &mut storage, smallvec![*deploy.id()]);
     assert_eq!(response, vec![Some(deploy.as_ref().clone())]);
 
-    // Also ensure we can retrieve just the header.
-    let response = harness.send_request(&mut storage, |responder| {
-        StorageRequest::GetDeployHeaders {
-            deploy_hashes: vec![*deploy.id()],
-            responder,
-        }
-        .into()
-    });
-    assert_eq!(response, vec![Some(deploy.header().clone())]);
-
     // Finally try to get the metadata as well. Since we did not store any, we expect empty default
     // metadata to present.
     let (deploy_response, metadata_response) = harness
@@ -1152,3 +1178,327 @@ fn should_hard_reset() {
     // Test with a hard reset to era 0, deleting all blocks and associated data.
     check(0);
 }
+
+#[test]
+fn should_create_subdir_named_after_network() {
+    let harness = ComponentHarness::default();
+    let cfg = new_config(&harness);
+
+    let storage = Storage::new(
+        &WithDir::new(harness.tmp.path(), cfg.clone()),
+        None,
+        ProtocolVersion::from_parts(1, 0, 0),
+        false,
+        "test",
+    )
+    .unwrap();
+
+    let expected_path = cfg.path.join("test");
+
+    assert!(expected_path.exists());
+    assert_eq!(expected_path, storage.root_path());
+}
+
+#[test]
+fn should_not_try_to_move_nonexistent_files() {
+    let harness = ComponentHarness::default();
+    let cfg = new_config(&harness);
+    let file_names = ["temp.txt"];
+
+    let expected = should_move_storage_files_to_network_subdir(&cfg.path, &file_names).unwrap();
+
+    assert!(!expected);
+}
+
+#[test]
+fn should_move_files_if_they_exist() {
+    let harness = ComponentHarness::default();
+    let cfg = new_config(&harness);
+    let file_names = ["temp1.txt", "temp2.txt", "temp3.txt"];
+
+    // Storage will create this in the constructor,
+    // doing this manually since we're not calling the constructor in this test.
+    fs::create_dir(cfg.path.clone()).unwrap();
+
+    // create empty files for testing.
+    File::create(cfg.path.join(file_names[0])).unwrap();
+    File::create(cfg.path.join(file_names[1])).unwrap();
+    File::create(cfg.path.join(file_names[2])).unwrap();
+
+    let expected = should_move_storage_files_to_network_subdir(&cfg.path, &file_names).unwrap();
+
+    assert!(expected);
+}
+
+#[test]
+fn should_return_error_if_files_missing() {
+    let harness = ComponentHarness::default();
+    let cfg = new_config(&harness);
+    let file_names = ["temp1.txt", "temp2.txt", "temp3.txt"];
+
+    // Storage will create this in the constructor,
+    // doing this manually since we're not calling the constructor in this test.
+    fs::create_dir(cfg.path.clone()).unwrap();
+
+    // create empty files for testing, but not all of the files.
+    File::create(cfg.path.join(file_names[1])).unwrap();
+    File::create(cfg.path.join(file_names[2])).unwrap();
+
+    let actual = should_move_storage_files_to_network_subdir(&cfg.path, &file_names);
+
+    assert!(actual.is_err());
+}
+
+#[test]
+fn should_actually_move_specified_files() {
+    let harness = ComponentHarness::default();
+    let cfg = new_config(&harness);
+    let file_names = ["temp1.txt", "temp2.txt", "temp3.txt"];
+    let root = cfg.path;
+    let subdir = root.join("test");
+    let src_path1 = root.join(file_names[0]);
+    let src_path2 = root.join(file_names[1]);
+    let src_path3 = root.join(file_names[2]);
+    let dest_path1 = subdir.join(file_names[0]);
+    let dest_path2 = subdir.join(file_names[1]);
+    let dest_path3 = subdir.join(file_names[2]);
+
+    // Storage will create this in the constructor,
+    // doing this manually since we're not calling the constructor in this test.
+    fs::create_dir_all(subdir.clone()).unwrap();
+
+    // create empty files for testing.
+    File::create(src_path1.clone()).unwrap();
+    File::create(src_path2.clone()).unwrap();
+    File::create(src_path3.clone()).unwrap();
+
+    assert!(src_path1.exists());
+    assert!(src_path2.exists());
+    assert!(src_path3.exists());
+
+    let result = move_storage_files_to_network_subdir(&root, &subdir, &file_names);
+
+    assert!(result.is_ok());
+    assert!(!src_path1.exists());
+    assert!(!src_path2.exists());
+    assert!(!src_path3.exists());
+    assert!(dest_path1.exists());
+    assert!(dest_path2.exists());
+    assert!(dest_path3.exists());
+}
+
+#[derive(Debug, Clone, PartialEq)]
+struct DatabaseEntriesSnapshot {
+    block_body_keys: HashSet<Digest>,
+    deploy_hashes_keys: HashSet<Digest>,
+    transfer_hashes_keys: HashSet<Digest>,
+    proposer_keys: HashSet<Digest>,
+}
+
+impl DatabaseEntriesSnapshot {
+    fn from_storage(storage: &Storage) -> DatabaseEntriesSnapshot {
+        let txn = storage.env.begin_ro_txn().unwrap();
+
+        let mut cursor = txn.open_ro_cursor(storage.block_body_v2_db).unwrap();
+        let block_body_keys = cursor
+            .iter()
+            .map(|(raw_key, _)| Digest::try_from(raw_key).unwrap())
+            .collect();
+        drop(cursor); // borrow checker complains without this
+
+        let mut cursor = txn.open_ro_cursor(storage.deploy_hashes_db).unwrap();
+        let deploy_hashes_keys = cursor
+            .iter()
+            .map(|(raw_key, _)| Digest::try_from(raw_key).unwrap())
+            .collect();
+        drop(cursor); // borrow checker complains without this
+
+        let mut cursor = txn.open_ro_cursor(storage.transfer_hashes_db).unwrap();
+        let transfer_hashes_keys = cursor
+            .iter()
+            .map(|(raw_key, _)| Digest::try_from(raw_key).unwrap())
+            .collect();
+        drop(cursor); // borrow checker complains without this
+
+        let mut cursor = txn.open_ro_cursor(storage.proposer_db).unwrap();
+        let proposer_keys = cursor
+            .iter()
+            .map(|(raw_key, _)| Digest::try_from(raw_key).unwrap())
+            .collect();
+        drop(cursor); // borrow checker complains without this
+
+        txn.commit().unwrap();
+
+        DatabaseEntriesSnapshot {
+            block_body_keys,
+            deploy_hashes_keys,
+            transfer_hashes_keys,
+            proposer_keys,
+        }
+    }
+}
+
+#[test]
+fn should_garbage_collect() {
+    let blocks_count = 9_usize;
+    let blocks_per_era = 3;
+    let mut harness = ComponentHarness::default();
+    let mut storage = storage_fixture(&harness);
+
+    // Create and store 9 blocks, 0-2 in era 0, 3-5 in era 1, and 6-8 in era 2.
+    let blocks: Vec<Block> = (0..blocks_count)
+        .map(|height| {
+            let is_switch = height % blocks_per_era == blocks_per_era - 1;
+            Block::random_with_specifics(
+                &mut harness.rng,
+                EraId::from((height / blocks_per_era) as u64),
+                height as u64,
+                ProtocolVersion::from_parts(1, 4, 0), // so that they are stored in v2 scheme
+                is_switch,
+            )
+        })
+        .collect();
+
+    let mut snapshots = vec![];
+
+    for block in &blocks {
+        assert!(put_block(
+            &mut harness,
+            &mut storage,
+            Box::new(block.clone())
+        ));
+        // store the storage state after a switch block for later comparison
+        if block.header().is_switch_block() {
+            snapshots.push(DatabaseEntriesSnapshot::from_storage(&storage));
+        }
+    }
+
+    let check = |reset_era: usize| {
+        // Initialize a new storage with a hard reset to the given era, deleting blocks from that
+        // era onwards.
+        let storage = storage_fixture_with_hard_reset_and_protocol_version(
+            &harness,
+            EraId::from(reset_era as u64),
+            ProtocolVersion::from_parts(1, 5, 0), /* this is needed because blocks with later
+                                                   * versions aren't removed on hard resets */
+        );
+
+        // Hard reset should remove headers, but not block bodies
+        let snapshot = DatabaseEntriesSnapshot::from_storage(&storage);
+        assert_eq!(snapshot, snapshots[reset_era]);
+
+        // Run garbage collection
+        let txn = storage.env.begin_ro_txn().unwrap();
+
+        let block_header_map =
+            construct_block_body_to_block_header_reverse_lookup(&txn, &storage.block_header_db)
+                .unwrap();
+        txn.commit().unwrap();
+
+        let mut txn = storage.env.begin_rw_txn().unwrap();
+        garbage_collect_block_body_v2_db(
+            &mut txn,
+            &storage.block_body_v2_db,
+            &storage.deploy_hashes_db,
+            &storage.transfer_hashes_db,
+            &storage.proposer_db,
+            &block_header_map,
+        )
+        .unwrap();
+        txn.commit().unwrap();
+
+        // Garbage collection after removal of blocks from reset_era should revert the state of
+        // block bodies to what it was after reset_era - 1.
+        let snapshot = DatabaseEntriesSnapshot::from_storage(&storage);
+        assert_eq!(snapshot, snapshots[reset_era - 1]);
+    };
+
+    check(2);
+    check(1);
+}
+
+#[test]
+fn can_put_and_get_blocks_v2() {
+    let num_blocks = 10;
+    let mut harness = ComponentHarness::default();
+    let mut storage = storage_fixture(&harness);
+
+    let era_id = harness.rng.gen_range(0..10).into();
+    let height = harness.rng.gen_range(0..100);
+
+    let mut blocks = vec![];
+
+    for i in 0..num_blocks {
+        let block = Block::random_with_specifics(
+            &mut harness.rng,
+            era_id,
+            height + i,
+            HashingAlgorithmVersion::HASH_V2_PROTOCOL_VERSION,
+            i == num_blocks - 1,
+        );
+
+        blocks.push(block.clone());
+
+        assert!(put_block(
+            &mut harness,
+            &mut storage,
+            Box::new(block.clone())
+        ));
+
+        let mut txn = storage.env.begin_ro_txn().unwrap();
+        let block_body_merkle = block.body().merklize();
+
+        for (node_hash, value_hash, proof_of_rest) in
+            block_body_merkle.clone().take_hashes_and_proofs()
+        {
+            assert_eq!(
+                txn.get_value_bytesrepr::<_, (Digest, Digest)>(
+                    storage.block_body_v2_db,
+                    &node_hash
+                )
+                .unwrap()
+                .unwrap(),
+                (value_hash, proof_of_rest)
+            );
+        }
+
+        assert_eq!(
+            txn.get_value_bytesrepr::<_, Vec<DeployHash>>(
+                storage.deploy_hashes_db,
+                block_body_merkle.deploy_hashes.value_hash()
+            )
+            .unwrap()
+            .unwrap(),
+            block.body().deploy_hashes().clone()
+        );
+
+        assert_eq!(
+            txn.get_value_bytesrepr::<_, Vec<DeployHash>>(
+                storage.transfer_hashes_db,
+                block_body_merkle.transfer_hashes.value_hash()
+            )
+            .unwrap()
+            .unwrap(),
+            block.body().transfer_hashes().clone()
+        );
+
+        assert_eq!(
+            txn.get_value_bytesrepr::<_, PublicKey>(
+                storage.proposer_db,
+                block_body_merkle.proposer.value_hash()
+            )
+            .unwrap()
+            .unwrap(),
+            *block.body().proposer()
+        );
+
+        txn.commit().unwrap();
+    }
+
+    for (i, expected_block) in blocks.into_iter().enumerate() {
+        assert_eq!(
+            get_block_at_height(&mut harness, &mut storage, height + i as u64),
+            Some(expected_block)
+        );
+    }
+}
