@@ -1,11 +1,11 @@
-use std::{env, fs, io, path::PathBuf};
+use std::{env, fs, io, path::PathBuf, sync::Arc};
 
 use serde::{Deserialize, Serialize};
 use thiserror::Error;
 use toml::de::Error as TomlDecodeError;
 use tracing::info;
 
-use casper_execution_engine::shared::newtypes::Blake2bHash;
+use casper_hashing::Digest;
 use casper_types::{ProtocolVersion, PublicKey, SecretKey, Signature};
 
 use crate::{
@@ -15,9 +15,6 @@ use crate::{
     utils::{LoadError, Loadable, WithDir},
 };
 
-// This will be changed in favour of an actual old config type when the migration is not a no-op.
-type OldConfig = toml::Value;
-
 /// The name of the file for recording the new global state hash after a data migration.
 const POST_MIGRATION_STATE_HASH_FILENAME: &str = "post-migration-state-hash";
 /// The folder under which the post-migration-state-hash file is written.
@@ -25,9 +22,11 @@ const CONFIG_ROOT_DIR: &str = "/etc/casper";
 /// Environment variable to override the config root dir.
 const CONFIG_ROOT_DIR_OVERRIDE: &str = "CASPER_CONFIG_DIR";
 
+// TODO - remove once used.
+#[allow(unused)]
 /// Error returned as a result of migrating data.
 #[derive(Debug, Error)]
-pub enum Error {
+pub(crate) enum Error {
     /// Error serializing state hash info.
     #[error("error serializing state hash info: {0}")]
     SerializeStateHashInfo(bincode::Error),
@@ -87,7 +86,7 @@ pub enum Error {
 
 #[derive(Serialize, Deserialize)]
 struct PostMigrationInfo {
-    state_hash: Blake2bHash,
+    state_hash: Digest,
     protocol_version: ProtocolVersion,
 }
 
@@ -107,7 +106,7 @@ struct SignedPostMigrationInfo {
 pub(crate) fn read_post_migration_info(
     protocol_version: ProtocolVersion,
     public_key: &PublicKey,
-) -> Result<Option<Blake2bHash>, Error> {
+) -> Result<Option<Digest>, Error> {
     do_read_post_migration_info(protocol_version, public_key, info_path())
 }
 
@@ -117,7 +116,7 @@ fn do_read_post_migration_info(
     protocol_version: ProtocolVersion,
     public_key: &PublicKey,
     path: PathBuf,
-) -> Result<Option<Blake2bHash>, Error> {
+) -> Result<Option<Digest>, Error> {
     // If the file doesn't exist, return `Ok(None)`.
     if !path.is_file() {
         return Ok(None);
@@ -156,7 +155,7 @@ fn do_read_post_migration_info(
 /// This must be called after a data migration in order to allow the node to read in the new root
 /// state on restart.
 fn write_post_migration_info(
-    state_hash: Blake2bHash,
+    state_hash: Digest,
     new_protocol_version: ProtocolVersion,
     secret_key: &SecretKey,
     path: PathBuf,
@@ -196,8 +195,8 @@ fn info_path() -> PathBuf {
 }
 
 /// Migrates data from that specified in the old config file to that specified in the new one.
-pub fn migrate_data(
-    _old_config: WithDir<OldConfig>,
+pub(crate) fn migrate_data(
+    _old_config: WithDir<toml::Value>,
     new_config: WithDir<Config>,
 ) -> Result<(), Error> {
     let (new_root, new_config) = new_config.into_parts();
@@ -205,16 +204,16 @@ pub fn migrate_data(
         .map_err(Error::LoadChainspec)?
         .protocol_config
         .version;
-    let secret_key = new_config
+    let secret_key: Arc<SecretKey> = new_config
         .consensus
         .secret_key_path
         .load(&new_root)
         .map_err(Error::LoadSecretKey)?;
 
     // Get this by actually migrating the global state data.
-    let state_hash = Blake2bHash::default();
+    let state_hash = Digest::default();
 
-    if state_hash != Blake2bHash::default() {
+    if state_hash != Digest::default() {
         write_post_migration_info(state_hash, new_protocol_version, &secret_key, info_path())?;
     }
 
@@ -234,7 +233,7 @@ mod tests {
         let info_path = tempdir.path().join(POST_MIGRATION_STATE_HASH_FILENAME);
 
         let mut rng = crate::new_rng();
-        let state_hash = Blake2bHash::new(&[rng.gen()]);
+        let state_hash = Digest::hash(&[rng.gen()]);
         let protocol_version = ProtocolVersion::from_parts(rng.gen(), rng.gen(), rng.gen());
         let secret_key = SecretKey::random(&mut rng);
 
@@ -262,7 +261,7 @@ mod tests {
         assert!(maybe_hash.is_none());
 
         // Create the info file and check we can read it.
-        let state_hash = Blake2bHash::new(&[rng.gen()]);
+        let state_hash = Digest::hash(&[rng.gen()]);
         write_post_migration_info(state_hash, protocol_version, &secret_key, info_path.clone())
             .unwrap();
         assert!(
@@ -295,7 +294,7 @@ mod tests {
 
         // Should return `Err` if the signature is invalid.
         let other_secret_key = SecretKey::random(&mut rng);
-        let state_hash = Blake2bHash::new(&[rng.gen()]);
+        let state_hash = Digest::hash(&[rng.gen()]);
         write_post_migration_info(
             state_hash,
             protocol_version,
