@@ -10,7 +10,6 @@ use std::{
 
 use datasize::DataSize;
 use derive_more::Display;
-use hex::FromHexError;
 use itertools::Itertools;
 use num_traits::Zero;
 use once_cell::sync::Lazy;
@@ -237,8 +236,8 @@ pub enum Error {
     InvalidPayment,
 }
 
-impl From<FromHexError> for Error {
-    fn from(error: FromHexError) -> Self {
+impl From<base16::DecodeError> for Error {
+    fn from(error: base16::DecodeError) -> Self {
         Error::DecodeFromJson(Box::new(error))
     }
 }
@@ -955,7 +954,7 @@ impl Deploy {
         };
         let secret_key = SecretKey::random(rng);
         Deploy::new(
-            deploy.header.timestamp,
+            Timestamp::now(),
             deploy.header.ttl,
             deploy.header.gas_price,
             deploy.header.dependencies,
@@ -998,15 +997,15 @@ impl Deploy {
     pub(crate) fn random_with_missing_payment_contract_by_hash(rng: &mut TestRng) -> Self {
         let payment = ExecutableDeployItem::StoredContractByHash {
             hash: [19; 32].into(),
-            entry_point: "non-existent-entry-point".to_string(),
+            entry_point: "call".to_string(),
             args: Default::default(),
         };
         Self::random_transfer_with_payment(rng, payment)
     }
 
     pub(crate) fn random_with_missing_entry_point_in_payment_contract(rng: &mut TestRng) -> Self {
-        let payment = ExecutableDeployItem::StoredContractByName {
-            name: "Test".to_string(),
+        let payment = ExecutableDeployItem::StoredContractByHash {
+            hash: [19; 32].into(),
             entry_point: "non-existent-entry-point".to_string(),
             args: Default::default(),
         };
@@ -1036,8 +1035,8 @@ impl Deploy {
     pub(crate) fn random_with_nonexistent_contract_version_in_payment_package(
         rng: &mut TestRng,
     ) -> Self {
-        let payment = ExecutableDeployItem::StoredVersionedContractByName {
-            name: "Test".to_string(),
+        let payment = ExecutableDeployItem::StoredVersionedContractByHash {
+            hash: [19; 32].into(),
             version: Some(6u32),
             entry_point: "non-existent-entry-point".to_string(),
             args: Default::default(),
@@ -1064,8 +1063,8 @@ impl Deploy {
     }
 
     pub(crate) fn random_with_missing_entry_point_in_session_contract(rng: &mut TestRng) -> Self {
-        let session = ExecutableDeployItem::StoredContractByName {
-            name: "Test".to_string(),
+        let session = ExecutableDeployItem::StoredContractByHash {
+            hash: [19; 32].into(),
             entry_point: "non-existent-entry-point".to_string(),
             args: Default::default(),
         };
@@ -1095,8 +1094,8 @@ impl Deploy {
     pub(crate) fn random_with_nonexistent_contract_version_in_session_package(
         rng: &mut TestRng,
     ) -> Self {
-        let session = ExecutableDeployItem::StoredVersionedContractByName {
-            name: "Test".to_string(),
+        let session = ExecutableDeployItem::StoredVersionedContractByHash {
+            hash: [19; 32].into(),
             version: Some(6u32),
             entry_point: "non-existent-entry-point".to_string(),
             args: Default::default(),
@@ -1146,6 +1145,23 @@ impl Deploy {
         Self::random_transfer_with_session(rng, session)
     }
 
+    pub(crate) fn random_expired_deploy(rng: &mut TestRng) -> Self {
+        let deploy = Self::random_valid_native_transfer(rng);
+        let secret_key = SecretKey::random(rng);
+
+        Deploy::new(
+            Timestamp::zero(),
+            TimeDiff::from_seconds(1u32),
+            deploy.header.gas_price,
+            deploy.header.dependencies,
+            deploy.header.chain_name,
+            deploy.payment,
+            deploy.session,
+            &secret_key,
+            None,
+        )
+    }
+
     /// Creates a deploy with native transfer as payment code.
     pub(crate) fn random_with_native_transfer_in_payment_logic(rng: &mut TestRng) -> Self {
         let transfer_args = runtime_args! {
